@@ -1062,7 +1062,7 @@ class MultiViewModel(list, BaseViewModel):
       '''
       menu_item = None
       for view in self.view_manager:
-        menu_item = gtk.RadioMenuItem(label = view.view_name)
+        menu_item = gtk.RadioMenuItem(label = _(view.view_name))
         menu_item.set_name(view.view_name)
         menu_item.connect('toggled', self._onItemToggled, view, context_plugin)
         menu_item.set_active(view == context_plugin.get_parent())
@@ -1071,7 +1071,7 @@ class MultiViewModel(list, BaseViewModel):
       menu_item = gtk.SeparatorMenuItem()
       self.append(menu_item)
       menu_item.show()
-      menu_item = gtk.MenuItem(label=_('<i>_New view...</i>'))
+      menu_item = gtk.MenuItem(label="<i>" + _('_New view...') + "</i>")
       menu_item.get_child().set_use_markup(True)
       menu_item.connect('activate', self._onItemActivated, 
                         context_plugin, transient_window)
